==> making_with_code_cli-1.3.0-py3-none-any.whl: making_with_code_cli/setup/__init__.py <==
import click
from subprocess import run
import traceback
import yaml
from making_with_code_cli.mwc_accounts_api import MWCAccountsAPI
from making_with_code_cli.git_backend import get_backend
from making_with_code_cli.update import update
from making_with_code_cli.settings import (
    get_settings_path,
    read_settings, 
    write_settings,
)
from making_with_code_cli.styles import (
    address,
    question,
    info,
    debug as debug_fmt,
    confirm,
    error,
)
from making_with_code_cli.setup.tasks import (
    INTRO_MESSAGE,
    INTRO_NOTES,
    WORK_DIR_PERMISSIONS,
    Platform,
    choose_mwc_username,
    prompt_mwc_password,
    choose_work_dir,
    choose_course,
    choose_editor,
    MWCShellConfig,
    InstallCurl,
    InstallHomebrew,
    InstallXCode,
    WriteShellConfig,
    InstallPoetry,
    InstallGit,
    InstallTree,
    InstallVSCode,
    InstallImageMagick,
    InstallHttpie,
    InstallScipy,
    GitConfiguration,
)

@click.command()
@click.option("--config", help="Path to config file (default: ~/.mwc)")
@click.option("--debug", is_flag=True, help="Show debug-level output")
@click.pass_context
def setup(ctx, config, debug):
    """Set up the MWC command line interface"""
    settings = read_settings(config)
    if debug:
        sp = get_settings_path(config)
        click.echo(debug_fmt(f"Reading settings from {sp}"))
    rc_tasks = []
    click.echo(address(INTRO_MESSAGE))
    for note in INTRO_NOTES:
        click.echo(address(note, list_format=True))
    click.echo()
    settings['mwc_username'] = choose_mwc_username(settings.get("mwc_username"))
    api = MWCAccountsAPI()
    if settings.get('mwc_accounts_token'):
        try:
            status = api.get_status(settings['mwc_accounts_token'])
        except api.RequestFailed as bad_token:
            token = prompt_mwc_password(settings['mwc_username'])
            settings['mwc_accounts_token'] = token
            status = api.get_status(token)
    else:
        token = prompt_mwc_password(settings['mwc_username'])
        settings['mwc_accounts_token'] = token
        status = api.get_status(token)
    if debug:
        click.echo(debug_fmt("MWC Accounts Server status:"))
        click.echo(debug_fmt(str(status)))
    settings['mwc_git_token'] = status['git_token']
    settings['work_dir'] = str(choose_work_dir(settings.get("work_dir")).resolve())
    if Platform.detect() & (Platform.MAC | Platform.UBUNTU):
        settings['editor'] = choose_editor(settings.get('editor', 'code'))
    if debug:
        click.echo(info("MWC settings:"))
        click.echo(info(yaml.dump(settings), preformatted=True))
    write_settings(settings, config)

    task_classes = [
        MWCShellConfig,
        InstallCurl,
        InstallHomebrew,
        InstallXCode,
        InstallPoetry,
        WriteShellConfig,
        InstallGit,
        InstallTree,
        InstallVSCode,
        InstallImageMagick,
        InstallHttpie,
        #InstallScipy,
        GitConfiguration,
    ]
    errors = []
    for task_class in task_classes:
        try:
            task = task_class(settings, debug=debug)
            task.run_task_if_needed()
        except Exception as e:
            errors.append(task)
            click.echo(error('-' * 80))
            click.echo(error(f"{task.task_description} failed"))
            if debug:
                click.echo(debug_fmt(traceback.format_exc(), preformatted=True))
    if errors:
        click.echo(error(f"{len(errors)} setup tasks failed:"))
        for task in errors:
            click.echo(error(f"- {task.description}"))
    else:
        ctx.invoke(update, config=config)

==> making_with_code_cli-2.0.1-py3-none-any.whl: making_with_code_cli/setup/__init__.py <==
import click
from subprocess import run
import traceback
import yaml
from making_with_code_cli.mwc_accounts_api import MWCAccountsAPI
from making_with_code_cli.git_backend import get_backend
from making_with_code_cli.update import update
from making_with_code_cli.settings import (
    get_settings_path,
    read_settings, 
    write_settings,
)
from making_with_code_cli.styles import (
    address,
    question,
    info,
    debug as debug_fmt,
    confirm,
    error,
)
from making_with_code_cli.setup.tasks import (
    INTRO_MESSAGE,
    INTRO_NOTES,
    WORK_DIR_PERMISSIONS,
    Platform,
    choose_mwc_username,
    prompt_mwc_password,
    choose_work_dir,
    choose_course,
    choose_editor,
    MWCShellConfig,
    InstallHomebrew,
    InstallXCode,
    WriteShellConfig,
    InstallPoetry,
    InstallGit,
    InstallTree,
    InstallVSCode,
    InstallImageMagick,
    InstallHttpie,
    InstallScipy,
    GitConfiguration,
)

@click.command()
@click.option("--config", help="Path to config file (default: ~/.mwc)")
@click.option("--debug", is_flag=True, help="Show debug-level output")
@click.pass_context
def setup(ctx, config, debug):
    """Set up the MWC command line interface"""
    settings = read_settings(config)
    if debug:
        sp = get_settings_path(config)
        click.echo(debug_fmt(f"Reading settings from {sp}"))
    rc_tasks = []
    click.echo(address(INTRO_MESSAGE))
    for note in INTRO_NOTES:
        click.echo(address(note, list_format=True))
    click.echo()
    settings['mwc_username'] = choose_mwc_username(settings.get("mwc_username"))
    api = MWCAccountsAPI()
    if settings.get('mwc_accounts_token'):
        try:
            status = api.get_status(settings['mwc_accounts_token'])
        except api.RequestFailed as bad_token:
            token = prompt_mwc_password(settings['mwc_username'])
            settings['mwc_accounts_token'] = token
            status = api.get_status(token)
    else:
        token = prompt_mwc_password(settings['mwc_username'])
        settings['mwc_accounts_token'] = token
        status = api.get_status(token)
    if debug:
        click.echo(debug_fmt("MWC Accounts Server status:"))
        click.echo(debug_fmt(str(status)))
    settings['mwc_git_token'] = status['git_token']
    settings['work_dir'] = str(choose_work_dir(settings.get("work_dir")).resolve())
    if Platform.detect() & (Platform.MAC | Platform.UBUNTU):
        settings['editor'] = choose_editor(settings.get('editor', 'code'))
    if debug:
        click.echo(info("MWC settings:"))
        click.echo(info(yaml.dump(settings), preformatted=True))
    write_settings(settings, config)

    task_classes = [
        MWCShellConfig,
        InstallXCode,
        InstallPoetry,
        WriteShellConfig,
        InstallGit,
        InstallTree,
        InstallVSCode,
        InstallImageMagick,
        InstallHttpie,
        #InstallScipy,
        GitConfiguration,
    ]
    errors = []
    for task_class in task_classes:
        try:
            task = task_class(settings, debug=debug)
            task.run_task_if_needed()
        except Exception as e:
            errors.append(task)
            click.echo(error('-' * 80))
            click.echo(error(f"{task.description} failed"))
            if debug:
                click.echo(debug_fmt(traceback.format_exc(), preformatted=True))
    if errors:
        click.echo(error(f"{len(errors)} setup tasks failed:"))
        for task in errors:
            click.echo(error(f"- {task.description}"))
    else:
        ctx.invoke(update, config=config)
